from functools import wraps

from django.conf import settings
from django.http import HttpResponseBadRequest
from django.template.loader import render_to_string

from sentry.web.decorators import login_required


def requires_team(func):
    @wraps(func)
    @login_required
    def wrapped(request, *args, **kwargs):
        allowed = True
        restricted_teams = getattr(
            settings, 'OPENID_RESTRICT_ACCESS_TO_TEAMS', [])
        user_has_openid = (
            getattr(request.user, 'useropenid_set') is not None and
            request.user.useropenid_set.count())

        if restricted_teams and user_has_openid:
            teams = request.user.groups.filter(name__in=restricted_teams)
            allowed = teams.count()

        if not allowed:
            return HttpResponseBadRequest(render_to_string(
                'sentry/missing_permissions.html'))
        return func(request, *args, **kwargs)
    return wrapped
